==> ogre_1.7.4+dfsg1.orig.tar.xz: ogre-1.7.4+dfsg1/RenderSystems/GLES/include/OgreGLESDefaultHardwareBufferManager.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2008 Renato Araujo Oliveira Filho <renatox@gmail.com>
Copyright (c) 2000-2011 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __GLESDefaultHardwareBufferManager_H__
#define __GLESDefaultHardwareBufferManager_H__

#include "OgreGLESPrerequisites.h"
#include "OgreHardwareBufferManager.h"
#include "OgreHardwareVertexBuffer.h"
#include "OgreHardwareIndexBuffer.h"

namespace Ogre {
    /// Specialisation of HardwareVertexBuffer for emulation
    class _OgreGLESExport GLESDefaultHardwareVertexBuffer : public HardwareVertexBuffer
    {
        protected:
            unsigned char* mpData;
            /** See HardwareBuffer. */
            void* lockImpl(size_t offset, size_t length, LockOptions options);
            /** See HardwareBuffer. */
            void unlockImpl(void);

        public:
            GLESDefaultHardwareVertexBuffer(size_t vertexSize, size_t numVertices,
                                            HardwareBuffer::Usage usage);
            GLESDefaultHardwareVertexBuffer(HardwareBufferManagerBase* mgr, size_t vertexSize, size_t numVertices, 
                                            HardwareBuffer::Usage usage);
            virtual ~GLESDefaultHardwareVertexBuffer();
            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, const void* pSource,
                           bool discardWholeBuffer = false);
            /** Override HardwareBuffer to turn off all shadowing. */
            void* lock(size_t offset, size_t length, LockOptions options);
            /** Override HardwareBuffer to turn off all shadowing. */
            void unlock(void);

            void* getDataPtr(size_t offset) const { return (void*)(mpData + offset); }
    };

    /// Specialisation of HardwareIndexBuffer for emulation
    class _OgreGLESExport GLESDefaultHardwareIndexBuffer : public HardwareIndexBuffer
    {
        protected:
            unsigned char* mpData;
            /** See HardwareBuffer. */
            void* lockImpl(size_t offset, size_t length, LockOptions options);
            /** See HardwareBuffer. */
            void unlockImpl(void);

        public:
            GLESDefaultHardwareIndexBuffer(IndexType idxType, size_t numIndexes, HardwareBuffer::Usage usage);
            virtual ~GLESDefaultHardwareIndexBuffer();
            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, const void* pSource,
                    bool discardWholeBuffer = false);
            /** Override HardwareBuffer to turn off all shadowing. */
            void* lock(size_t offset, size_t length, LockOptions options);
            /** Override HardwareBuffer to turn off all shadowing. */
            void unlock(void);

            void* getDataPtr(size_t offset) const { return (void*)(mpData + offset); }
    };

    /** Specialisation of HardwareBufferManager to emulate hardware buffers.
    @remarks
        You might want to instantiate this class if you want to utilise
        classes like MeshSerializer without having initialised the 
        rendering system (which is required to create a 'real' hardware
        buffer manager.
    */
    class _OgreGLESExport GLESDefaultHardwareBufferManagerBase : public HardwareBufferManagerBase
    {
        public:
            GLESDefaultHardwareBufferManagerBase();
            virtual ~GLESDefaultHardwareBufferManagerBase();
            /// Creates a vertex buffer
            HardwareVertexBufferSharedPtr
                createVertexBuffer(size_t vertexSize, size_t numVerts,
                    HardwareBuffer::Usage usage, bool useShadowBuffer = false);
            /// Create a hardware vertex buffer
            HardwareIndexBufferSharedPtr
                createIndexBuffer(HardwareIndexBuffer::IndexType itype, size_t numIndexes,
                    HardwareBuffer::Usage usage, bool useShadowBuffer = false);
            /// Create a render to vertex buffer
	    RenderToVertexBufferSharedPtr createRenderToVertexBuffer(void);
    };

	/// GLESDefaultHardwareBufferManagerBase as a Singleton
	class _OgreGLESExport GLESDefaultHardwareBufferManager : public HardwareBufferManager
	{
	public:
		GLESDefaultHardwareBufferManager()
			: HardwareBufferManager(OGRE_NEW GLESDefaultHardwareBufferManagerBase()) 
		{

		}
		~GLESDefaultHardwareBufferManager()
		{
			OGRE_DELETE mImpl;
		}
	};
}

#endif

==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/RenderSystems/GLES/include/OgreGLESDefaultHardwareBufferManager.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2008 Renato Araujo Oliveira Filho <renatox@gmail.com>
Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __GLESDefaultHardwareBufferManager_H__
#define __GLESDefaultHardwareBufferManager_H__

#include "OgreGLESPrerequisites.h"
#include "OgreHardwareBufferManager.h"
#include "OgreHardwareVertexBuffer.h"
#include "OgreHardwareIndexBuffer.h"

namespace Ogre {
    /// Specialisation of HardwareVertexBuffer for emulation
    class _OgreGLESExport GLESDefaultHardwareVertexBuffer : public HardwareVertexBuffer
    {
        protected:
            unsigned char* mData;
            /** See HardwareBuffer. */
            void* lockImpl(size_t offset, size_t length, LockOptions options);
            /** See HardwareBuffer. */
            void unlockImpl(void);

        public:
            GLESDefaultHardwareVertexBuffer(size_t vertexSize, size_t numVertices,
                                            HardwareBuffer::Usage usage);
            GLESDefaultHardwareVertexBuffer(HardwareBufferManagerBase* mgr, size_t vertexSize, size_t numVertices, 
                                            HardwareBuffer::Usage usage);
            virtual ~GLESDefaultHardwareVertexBuffer();
            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, const void* pSource,
                           bool discardWholeBuffer = false);
            /** Override HardwareBuffer to turn off all shadowing. */
            void* lock(size_t offset, size_t length, LockOptions options);
            /** Override HardwareBuffer to turn off all shadowing. */
            void unlock(void);

            void* getDataPtr(size_t offset) const { return (void*)(mData + offset); }
    };

    /// Specialisation of HardwareIndexBuffer for emulation
    class _OgreGLESExport GLESDefaultHardwareIndexBuffer : public HardwareIndexBuffer
    {
        protected:
            unsigned char* mData;
            /** See HardwareBuffer. */
            void* lockImpl(size_t offset, size_t length, LockOptions options);
            /** See HardwareBuffer. */
            void unlockImpl(void);

        public:
            GLESDefaultHardwareIndexBuffer(IndexType idxType, size_t numIndexes, HardwareBuffer::Usage usage);
            virtual ~GLESDefaultHardwareIndexBuffer();
            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, const void* pSource,
                    bool discardWholeBuffer = false);
            /** Override HardwareBuffer to turn off all shadowing. */
            void* lock(size_t offset, size_t length, LockOptions options);
            /** Override HardwareBuffer to turn off all shadowing. */
            void unlock(void);

            void* getDataPtr(size_t offset) const { return (void*)(mData + offset); }
    };

    /** Specialisation of HardwareBufferManager to emulate hardware buffers.
    @remarks
        You might want to instantiate this class if you want to utilise
        classes like MeshSerializer without having initialised the 
        rendering system (which is required to create a 'real' hardware
        buffer manager.
    */
    class _OgreGLESExport GLESDefaultHardwareBufferManagerBase : public HardwareBufferManagerBase
    {
        public:
            GLESDefaultHardwareBufferManagerBase();
            virtual ~GLESDefaultHardwareBufferManagerBase();
            /// Creates a vertex buffer
            HardwareVertexBufferSharedPtr
                createVertexBuffer(size_t vertexSize, size_t numVerts,
                    HardwareBuffer::Usage usage, bool useShadowBuffer = false);
            /// Create a hardware vertex buffer
            HardwareIndexBufferSharedPtr
                createIndexBuffer(HardwareIndexBuffer::IndexType itype, size_t numIndexes,
                    HardwareBuffer::Usage usage, bool useShadowBuffer = false);
            /// Create a render to vertex buffer
	    RenderToVertexBufferSharedPtr createRenderToVertexBuffer(void);
        HardwareUniformBufferSharedPtr
        createUniformBuffer(size_t sizeBytes, HardwareBuffer::Usage usage,bool useShadowBuffer, const String& name = "")
        {
            OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR,
                        "GLES does not support uniform buffer objects",
                        "GLESDefaultHardwareBufferManagerBase::createUniformBuffer");
        }
		HardwareCounterBufferSharedPtr createCounterBuffer(size_t sizeBytes,
                                                           HardwareBuffer::Usage usage = HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE,
                                                           bool useShadowBuffer = false, const String& name = "")
        {
            OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR,
                        "GLES does not support atomic counter buffers",
                        "GLESDefaultHardwareBufferManagerBase::createCounterBuffer");
        }
    };

	/// GLESDefaultHardwareBufferManagerBase as a Singleton
	class _OgreGLESExport GLESDefaultHardwareBufferManager : public HardwareBufferManager
	{
	public:
		GLESDefaultHardwareBufferManager()
			: HardwareBufferManager(OGRE_NEW GLESDefaultHardwareBufferManagerBase()) 
		{

		}
		~GLESDefaultHardwareBufferManager()
		{
			OGRE_DELETE mImpl;
		}
        HardwareUniformBufferSharedPtr
        createUniformBuffer(size_t sizeBytes, HardwareBuffer::Usage usage,bool useShadowBuffer, const String& name = "")
        {
            OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR,
                        "GLES does not support render to vertex buffer objects",
                        "GLESDefaultHardwareBufferManager::createUniformBuffer");
        }
	};
}

#endif
